@@ -5,8 +5,6 @@ use base 'Giblog::Command::new';
 use strict;
 use warnings;
 
-sub run { shift->SUPER::run(@_) }
-
 1;
 
 =head1 NAME
@@ -17,9 +15,3 @@ Giblog::Command::new_zemi - new_zemi command
 
 L<Giblog::Command::new_zemi> inherits all methods from L<Giblog::Command::new> and
 implements the following new ones.
-
-=head2 run
-
-  $command->run(@argv);
-
-Execute new_zemi command.
